@@ -44,8 +44,8 @@ int main(int argc,char **argv)
     printf("=========================\n\n");
     printf("Please Select An Option\n");
     printf("1.Create A G.A.N.N And Teach It\n");
-    printf("2.Simulate An Existing G.A.N.N From GKDB\n");
-    printf("3.Create A G.A.N.N - Teach It And Simulate It\n");
+    printf("2.Run An Existing G.A.N.N From GKDB\n");
+    printf("3.Create A G.A.N.N - Teach It And Run It\n");
     printf("4.Exit\n");
     printf("Choice:");
     
@@ -78,8 +78,8 @@ int main(int argc,char **argv)
     
     {
     
-        //Unfinished
-        
+        //Simulate G.A.N.N At Running Mode
+        GNMS(1);
     
     }
     
@@ -90,7 +90,19 @@ int main(int argc,char **argv)
         //Create New G.A.N.N
         GSNMC();
         
-        //Unfinished
+        printf("Restoring Data...\n");
+        
+        //Load GIOD And GMap Data
+        GDMLoader();
+        
+        printf("Done!\n\n");
+        printf("Starting Simulation...\n\n");
+        
+        //Simulate G.A.N.N At Learning Mode
+        GNMS(0);
+        
+        //Simulate G.A.N.N At Running Mode
+        GNMS(1);
     
     }
     
