@@ -30,6 +30,9 @@ float GGenData(int FuncType,float Val)
 
 {
 
+    //Randomize
+    GRand();
+    
     //Check Function Type (0:Binary,1:Real)
     if (FuncType==0 && Val==0.0)
     
@@ -71,6 +74,9 @@ float GGenData(float Val1,float Val2)
 
 {
 
+    //Randomize
+    GRand();
+    
     //Check Range
     if (Val2>=Val1)
     
