@@ -264,7 +264,11 @@ void GNMS(int SimFunc)
                 
                     printf("GPin:%i\n",i+1);
                     printf("Min Value:%.1f\n",GMinData[i]);
-                    printf("Max Value:%.1f\n",GMaxData[i]);
+                    
+                    if (GMaxData[i]==0.0)
+                        printf("Maximum Value:N/A\n");
+                    else
+                        printf("Max Value:%.1f\n",GMaxData[i]);
                 
                 }
                 
