@@ -31,6 +31,11 @@ void GRMC()
     int i,j;
     
     //User Interaction
+    printf("# Geeks Runtime Manager Console #\n");
+    printf("\n");
+    printf("\n\n");
+    
+    printf("#  #\n");
     
     //Create Geeks Hash Table
     
