@@ -29,6 +29,7 @@ void GSaveData(GNeuron *GMatrix)
 
     //Variables
     int i,j;
+    long k;
     FILE *FileToSave;
     
     //Initialize GKDB
@@ -58,8 +59,19 @@ void GSaveData(GNeuron *GMatrix)
     
     }
     
+    //Get File Position Indicator
+    k=ftell(FileToSave);
+    
     //Close GKDB
     fclose(FileToSave);
+    
+    //Initialize GHT
+    FileToSave=fopen("GHT","a");
+    
+    fprintf(FileToSave,"%i\n",k);
+    
+    //Close GHT
+    fclose(FileToSave);
 
 }
 
