@@ -145,21 +145,33 @@ class GNeuron
     //Enable Neuron
     void Enable(int NFType);
     
-    //Set Input Data
+    //Input Data
     void InData(int InputPin,float Data);
     
     //Output Data
     float OutData();
     
+    //Set Neuron Function Type
+    void SetNFT(int NewNFT);
+    
+    //Set Sum
+    void SetSum(float NewSum);
+    
+    //Set Base
+    void SetBase(float NewBase);
+    
+    //Set Weights
+    void SetWeights(int WPin,float Weight);
+    
     //Get Neuron Function Type
     int GetNFT();
     
-    //Get Base
-    float GetBase();
-    
     //Get Sum
     float GetSum();
     
+    //Get Base
+    float GetBase();
+    
     //Get Input Data
     float GetInData(int DIndex);
     
@@ -174,6 +186,9 @@ float GErrStat(float *FirstData,float *LastData,int StatType);
 //Geeks Error Correction (Function)
 void GErrC(GNeuron *GMatrix,int GNIndex,float Err,int CheckType);
 
+//Geeks Runtime Manager Console
+void GRMC();
+
 //Geeks [I/O] Distribution And Map Loader (Function)
 void GDMLoader();
 
@@ -184,13 +199,13 @@ float GGenData(int FuncType,float Val);
 float GGenData(float Val1,float Val2);
 
 //Geeks Read Data (Function)
-int GReadData();
+int GReadData(GNeuron *GMatrix,int RegNum);
 
 //Geeks Save Data (Function)
 void GSaveData(GNeuron *GMatrix);
 
 //Geeks Remove Data (Function)
-void GRemData();
+void GRemData(GNeuron *GMatrix,int RegNum);
 
 //Geeks Socket And Neural Map Creator (Function)
 void GSNMC();
